@@ -2,12 +2,13 @@ package cli
 
 import (
 	"fmt"
-	"oh-my-posh/platform"
 	"os"
 	"os/exec"
 	"path/filepath"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+
 	"github.com/spf13/cobra"
 )
 
