@@ -2,18 +2,19 @@ package cli
 
 import (
 	"fmt"
-	"oh-my-posh/color"
-	"oh-my-posh/platform"
 	"strings"
 	"time"
 
+	"github.com/jandedobbeleer/oh-my-posh/color"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+
 	color2 "github.com/gookit/color"
 	"github.com/spf13/cobra"
 )
 
 // getCmd represents the get command
 var getCmd = &cobra.Command{
-	Use:   "get [shell|millis|accent|toggles]",
+	Use:   "get [shell|millis|accent|toggles|width]",
 	Short: "Get a value from oh-my-posh",
 	Long: `Get a value from oh-my-posh.
 
@@ -22,12 +23,14 @@ This command is used to get the value of the following variables:
 - shell
 - millis
 - accent
-- toggles`,
+- toggles
+- width`,
 	ValidArgs: []string{
 		"millis",
 		"shell",
 		"accent",
 		"toggles",
+		"width",
 	},
 	Args: NoArgsOrOneValidArg,
 	Run: func(cmd *cobra.Command, args []string) {
@@ -71,6 +74,13 @@ This command is used to get the value of the following variables:
 			for _, toggle := range toggles {
 				fmt.Println("- " + toggle)
 			}
+		case "width":
+			width, err := env.TerminalWidth()
+			if err != nil {
+				fmt.Println("error getting terminal width:", err.Error())
+				return
+			}
+			fmt.Println(width)
 		default:
 			_ = cmd.Help()
 		}
