@@ -1,9 +1,10 @@
 package cli
 
 import (
-	"oh-my-posh/platform"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+
 	"github.com/spf13/cobra"
 )
 
