@@ -2,8 +2,10 @@ package color
 
 import (
 	"fmt"
-	"oh-my-posh/platform"
 	"strconv"
+	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/platform"
 
 	"github.com/gookit/color"
 )
@@ -78,6 +80,14 @@ func (d *DefaultColors) AnsiColorFromString(colorString string, isBackground boo
 	if err == nil {
 		return colorFromName
 	}
+	if !strings.HasPrefix(colorString, "#") {
+		val, err := strconv.ParseUint(colorString, 10, 64)
+		if err != nil || val > 255 {
+			return emptyAnsiColor
+		}
+		c256 := color.C256(uint8(val), isBackground)
+		return AnsiColor(c256.RGBColor().String())
+	}
 	style := color.HEX(colorString, isBackground)
 	if !style.IsEmpty() {
 		return AnsiColor(style.String())
