@@ -1,9 +1,10 @@
 package color
 
 import (
-	"oh-my-posh/regex"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/regex"
+
 	"github.com/mattn/go-runewidth"
 )
 
