@@ -5,16 +5,17 @@ import (
 	json2 "encoding/json"
 	"fmt"
 	"io"
-	"oh-my-posh/color"
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
-	"oh-my-posh/segments"
-	"oh-my-posh/template"
 	"os"
 	"path/filepath"
 	"strings"
 	"time"
 
+	"github.com/jandedobbeleer/oh-my-posh/color"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/segments"
+	"github.com/jandedobbeleer/oh-my-posh/template"
+
 	"github.com/gookit/config/v2"
 	"github.com/gookit/config/v2/json"
 	"github.com/gookit/config/v2/toml"
@@ -112,11 +113,14 @@ func loadConfig(env platform.Environment) *Config {
 	config.AddDriver(yaml.Driver)
 	config.AddDriver(json.Driver)
 	config.AddDriver(toml.Driver)
-	config.WithOptions(func(opt *config.Options) {
-		opt.DecoderConfig = &mapstructure.DecoderConfig{
-			TagName: "json",
-		}
-	})
+
+	if config.Default().IsEmpty() {
+		config.WithOptions(func(opt *config.Options) {
+			opt.DecoderConfig = &mapstructure.DecoderConfig{
+				TagName: "json",
+			}
+		})
+	}
 
 	err := config.LoadFiles(configFile)
 	if err != nil {
