@@ -2,13 +2,14 @@ package engine
 
 import (
 	"fmt"
-	"oh-my-posh/color"
-	"oh-my-posh/console"
-	"oh-my-posh/platform"
-	"oh-my-posh/shell"
-	"oh-my-posh/template"
 	"strings"
 	"time"
+
+	"github.com/jandedobbeleer/oh-my-posh/color"
+	"github.com/jandedobbeleer/oh-my-posh/console"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/shell"
+	"github.com/jandedobbeleer/oh-my-posh/template"
 )
 
 type Engine struct {
@@ -37,10 +38,12 @@ func (e *Engine) writeANSI(text string) {
 }
 
 func (e *Engine) string() string {
-	return e.console.String()
+	text := e.console.String()
+	e.console.Reset()
+	return text
 }
 
-func (e *Engine) canWriteRPrompt(rprompt bool) bool {
+func (e *Engine) canWriteRightBlock(rprompt bool) bool {
 	if rprompt && (e.rprompt == "" || e.Plain) {
 		return false
 	}
@@ -103,10 +106,19 @@ func (e *Engine) printPWD() {
 }
 
 func (e *Engine) newline() {
-	e.write("\n")
+	// WARP terminal will remove \n from the prompt, so we hack a newline in
+	if e.isWarp() {
+		e.write(e.Ansi.LineBreak())
+	} else {
+		e.write("\n")
+	}
 	e.currentLineLength = 0
 }
 
+func (e *Engine) isWarp() bool {
+	return e.Env.Getenv("TERM_PROGRAM") == "WarpTerminal"
+}
+
 func (e *Engine) shouldFill(block *Block, length int) (string, bool) {
 	if len(block.Filler) == 0 {
 		return "", false
@@ -121,7 +133,6 @@ func (e *Engine) shouldFill(block *Block, length int) (string, bool) {
 	}
 	e.Writer.Write("", "", block.Filler)
 	filler, lenFiller := e.Writer.String()
-	e.Writer.Reset()
 	if lenFiller == 0 {
 		return "", false
 	}
@@ -177,7 +188,7 @@ func (e *Engine) renderBlock(block *Block) {
 		text, length := block.RenderSegments()
 		e.rpromptLength = length
 
-		if !e.canWriteRPrompt(false) {
+		if !e.canWriteRightBlock(false) {
 			switch block.Overflow {
 			case Break:
 				e.newline()
@@ -265,12 +276,23 @@ func (e *Engine) print() string {
 		if !e.Env.Flags().Eval {
 			break
 		}
+		// Warp doesn't support RPROMPT so we need to write it manually
+		if e.isWarp() {
+			e.write(e.Ansi.SaveCursorPosition())
+			e.write(e.Ansi.CarriageForward())
+			e.write(e.Ansi.GetCursorForRightWrite(e.rpromptLength, 0))
+			e.write(e.rprompt)
+			e.write(e.Ansi.RestoreCursorPosition())
+			// escape double quotes contained in the prompt
+			prompt := fmt.Sprintf("PS1=\"%s\"", strings.ReplaceAll(e.string(), `"`, `\"`))
+			return prompt
+		}
 		// escape double quotes contained in the prompt
 		prompt := fmt.Sprintf("PS1=\"%s\"", strings.ReplaceAll(e.string(), `"`, `\"`))
 		prompt += fmt.Sprintf("\nRPROMPT=\"%s\"", e.rprompt)
 		return prompt
 	case shell.PWSH, shell.PWSH5, shell.PLAIN, shell.NU:
-		if !e.canWriteRPrompt(true) {
+		if !e.canWriteRightBlock(true) {
 			break
 		}
 		e.write(e.Ansi.SaveCursorPosition())
@@ -279,11 +301,11 @@ func (e *Engine) print() string {
 		e.write(e.rprompt)
 		e.write(e.Ansi.RestoreCursorPosition())
 	case shell.BASH:
-		if !e.canWriteRPrompt(true) {
+		if !e.canWriteRightBlock(true) {
 			break
 		}
 		// in bash, the entire rprompt needs to be escaped for the prompt to be interpreted correctly
-		// see https://github.com/JanDeDobbeleer/oh-my-posh/pull/2398
+		// see https://github.com/jandedobbeleer/oh-my-posh/pull/2398
 		ansi := &color.Ansi{}
 		ansi.InitPlain()
 		prompt := ansi.SaveCursorPosition()
@@ -294,6 +316,7 @@ func (e *Engine) print() string {
 		prompt = e.Ansi.FormatText(prompt)
 		e.write(prompt)
 	}
+
 	return e.string()
 }
 
@@ -322,7 +345,7 @@ func (e *Engine) PrintTooltip(tip string) string {
 		Segments:  []*Segment{tooltip},
 	}
 	switch e.Env.Shell() {
-	case shell.ZSH, shell.CMD, shell.FISH:
+	case shell.ZSH, shell.CMD, shell.FISH, shell.PLAIN:
 		block.Init(e.Env, e.Writer, e.Ansi)
 		if !block.Enabled() {
 			return ""
@@ -411,7 +434,8 @@ func (e *Engine) PrintExtraPrompt(promptType ExtraPromptType) string {
 			return prompt
 		}
 		return str
-	case shell.PWSH, shell.PWSH5, shell.CMD, shell.BASH, shell.FISH, shell.NU:
+	case shell.PWSH, shell.PWSH5, shell.CMD, shell.BASH, shell.FISH, shell.NU, shell.PLAIN:
+		// Return the string and empty our buffer
 		str, _ := e.Writer.String()
 		return str
 	}
