@@ -7,11 +7,11 @@ import (
 	"strings"
 	"time"
 
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
-	"oh-my-posh/segments"
-	"oh-my-posh/shell"
-	"oh-my-posh/template"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/segments"
+	"github.com/jandedobbeleer/oh-my-posh/shell"
+	"github.com/jandedobbeleer/oh-my-posh/template"
 
 	c "golang.org/x/text/cases"
 	"golang.org/x/text/language"
@@ -36,13 +36,16 @@ type Segment struct {
 	Properties          properties.Map `json:"properties,omitempty"`
 	Interactive         bool           `json:"interactive,omitempty"`
 	Alias               string         `json:"alias,omitempty"`
+	MaxWidth            int            `json:"max_width,omitempty"`
+	MinWidth            int            `json:"min_width,omitempty"`
 
+	env             platform.Environment
 	writer          SegmentWriter
 	Enabled         bool `json:"-"`
 	text            string
-	env             platform.Environment
 	backgroundCache string
 	foregroundCache string
+	styleCache      SegmentStyle
 }
 
 // SegmentTiming holds the timing context for a segment
@@ -64,6 +67,20 @@ type SegmentWriter interface {
 // SegmentStyle the style of segment, for more information, see the constants
 type SegmentStyle string
 
+func (s *SegmentStyle) Resolve(env platform.Environment, context interface{}) SegmentStyle {
+	txtTemplate := &template.Text{
+		Context: context,
+		Env:     env,
+	}
+	txtTemplate.Template = string(*s)
+	value, err := txtTemplate.Render()
+	// default to Plain
+	if err != nil || len(value) == 0 {
+		return Plain
+	}
+	return SegmentStyle(value)
+}
+
 // SegmentType the type of segment, for more information, see the constants
 type SegmentType string
 
@@ -121,6 +138,8 @@ const (
 	GCP SegmentType = "gcp"
 	// GIT represents the git status and information
 	GIT SegmentType = "git"
+	// GITVERSION represents the gitversion information
+	GITVERSION SegmentType = "gitversion"
 	// GOLANG writes which go version is currently active
 	GOLANG SegmentType = "go"
 	// HASKELL segment
@@ -207,6 +226,84 @@ const (
 	YTM SegmentType = "ytm"
 )
 
+// Segments contains all available prompt segment writers.
+// Consumers of the library can also add their own segment writer.
+var Segments = map[SegmentType]func() SegmentWriter{
+	ANGULAR:       func() SegmentWriter { return &segments.Angular{} },
+	AWS:           func() SegmentWriter { return &segments.Aws{} },
+	AZ:            func() SegmentWriter { return &segments.Az{} },
+	AZFUNC:        func() SegmentWriter { return &segments.AzFunc{} },
+	BATTERY:       func() SegmentWriter { return &segments.Battery{} },
+	BREWFATHER:    func() SegmentWriter { return &segments.Brewfather{} },
+	CDS:           func() SegmentWriter { return &segments.Cds{} },
+	CF:            func() SegmentWriter { return &segments.Cf{} },
+	CFTARGET:      func() SegmentWriter { return &segments.CfTarget{} },
+	CMD:           func() SegmentWriter { return &segments.Cmd{} },
+	CONNECTION:    func() SegmentWriter { return &segments.Connection{} },
+	CRYSTAL:       func() SegmentWriter { return &segments.Crystal{} },
+	CMAKE:         func() SegmentWriter { return &segments.Cmake{} },
+	DART:          func() SegmentWriter { return &segments.Dart{} },
+	DENO:          func() SegmentWriter { return &segments.Deno{} },
+	DOTNET:        func() SegmentWriter { return &segments.Dotnet{} },
+	EXECUTIONTIME: func() SegmentWriter { return &segments.Executiontime{} },
+	EXIT:          func() SegmentWriter { return &segments.Exit{} },
+	FLUTTER:       func() SegmentWriter { return &segments.Flutter{} },
+	FOSSIL:        func() SegmentWriter { return &segments.Fossil{} },
+	GCP:           func() SegmentWriter { return &segments.Gcp{} },
+	GIT:           func() SegmentWriter { return &segments.Git{} },
+	GITVERSION:    func() SegmentWriter { return &segments.GitVersion{} },
+	GOLANG:        func() SegmentWriter { return &segments.Golang{} },
+	HASKELL:       func() SegmentWriter { return &segments.Haskell{} },
+	IPIFY:         func() SegmentWriter { return &segments.IPify{} },
+	ITERM:         func() SegmentWriter { return &segments.ITerm{} },
+	JAVA:          func() SegmentWriter { return &segments.Java{} },
+	JULIA:         func() SegmentWriter { return &segments.Julia{} },
+	KOTLIN:        func() SegmentWriter { return &segments.Kotlin{} },
+	KUBECTL:       func() SegmentWriter { return &segments.Kubectl{} },
+	LUA:           func() SegmentWriter { return &segments.Lua{} },
+	NBGV:          func() SegmentWriter { return &segments.Nbgv{} },
+	NIGHTSCOUT:    func() SegmentWriter { return &segments.Nightscout{} },
+	NODE:          func() SegmentWriter { return &segments.Node{} },
+	NPM:           func() SegmentWriter { return &segments.Npm{} },
+	NX:            func() SegmentWriter { return &segments.Nx{} },
+	OS:            func() SegmentWriter { return &segments.Os{} },
+	OWM:           func() SegmentWriter { return &segments.Owm{} },
+	PATH:          func() SegmentWriter { return &segments.Path{} },
+	PERL:          func() SegmentWriter { return &segments.Perl{} },
+	PHP:           func() SegmentWriter { return &segments.Php{} },
+	PLASTIC:       func() SegmentWriter { return &segments.Plastic{} },
+	PROJECT:       func() SegmentWriter { return &segments.Project{} },
+	PYTHON:        func() SegmentWriter { return &segments.Python{} },
+	R:             func() SegmentWriter { return &segments.R{} },
+	ROOT:          func() SegmentWriter { return &segments.Root{} },
+	RUBY:          func() SegmentWriter { return &segments.Ruby{} },
+	RUST:          func() SegmentWriter { return &segments.Rust{} },
+	SESSION:       func() SegmentWriter { return &segments.Session{} },
+	SHELL:         func() SegmentWriter { return &segments.Shell{} },
+	SPOTIFY:       func() SegmentWriter { return &segments.Spotify{} },
+	STRAVA:        func() SegmentWriter { return &segments.Strava{} },
+	SVN:           func() SegmentWriter { return &segments.Svn{} },
+	SWIFT:         func() SegmentWriter { return &segments.Swift{} },
+	SYSTEMINFO:    func() SegmentWriter { return &segments.SystemInfo{} },
+	TERRAFORM:     func() SegmentWriter { return &segments.Terraform{} },
+	TEXT:          func() SegmentWriter { return &segments.Text{} },
+	TIME:          func() SegmentWriter { return &segments.Time{} },
+	UI5TOOLING:    func() SegmentWriter { return &segments.UI5Tooling{} },
+	WAKATIME:      func() SegmentWriter { return &segments.Wakatime{} },
+	WINREG:        func() SegmentWriter { return &segments.WindowsRegistry{} },
+	WITHINGS:      func() SegmentWriter { return &segments.Withings{} },
+	XMAKE:         func() SegmentWriter { return &segments.XMake{} },
+	YTM:           func() SegmentWriter { return &segments.Ytm{} },
+}
+
+func (segment *Segment) style() SegmentStyle {
+	if len(segment.styleCache) != 0 {
+		return segment.styleCache
+	}
+	segment.styleCache = segment.Style.Resolve(segment.env, segment.writer)
+	return segment.styleCache
+}
+
 func (segment *Segment) shouldIncludeFolder() bool {
 	if segment.env == nil {
 		return true
@@ -217,7 +314,8 @@ func (segment *Segment) shouldIncludeFolder() bool {
 }
 
 func (segment *Segment) isPowerline() bool {
-	return segment.Style == Powerline || segment.Style == Accordion
+	style := segment.style()
+	return style == Powerline || style == Accordion
 }
 
 func (segment *Segment) cwdIncluded() bool {
@@ -271,80 +369,18 @@ func (segment *Segment) background() string {
 
 func (segment *Segment) mapSegmentWithWriter(env platform.Environment) error {
 	segment.env = env
-	functions := map[SegmentType]SegmentWriter{
-		ANGULAR:       &segments.Angular{},
-		AWS:           &segments.Aws{},
-		AZ:            &segments.Az{},
-		AZFUNC:        &segments.AzFunc{},
-		BATTERY:       &segments.Battery{},
-		BREWFATHER:    &segments.Brewfather{},
-		CDS:           &segments.Cds{},
-		CF:            &segments.Cf{},
-		CFTARGET:      &segments.CfTarget{},
-		CMD:           &segments.Cmd{},
-		CONNECTION:    &segments.Connection{},
-		CRYSTAL:       &segments.Crystal{},
-		CMAKE:         &segments.Cmake{},
-		DART:          &segments.Dart{},
-		DENO:          &segments.Deno{},
-		DOTNET:        &segments.Dotnet{},
-		EXECUTIONTIME: &segments.Executiontime{},
-		EXIT:          &segments.Exit{},
-		FLUTTER:       &segments.Flutter{},
-		FOSSIL:        &segments.Fossil{},
-		GCP:           &segments.Gcp{},
-		GIT:           &segments.Git{},
-		GOLANG:        &segments.Golang{},
-		HASKELL:       &segments.Haskell{},
-		IPIFY:         &segments.IPify{},
-		ITERM:         &segments.ITerm{},
-		JAVA:          &segments.Java{},
-		JULIA:         &segments.Julia{},
-		KOTLIN:        &segments.Kotlin{},
-		KUBECTL:       &segments.Kubectl{},
-		LUA:           &segments.Lua{},
-		NBGV:          &segments.Nbgv{},
-		NIGHTSCOUT:    &segments.Nightscout{},
-		NODE:          &segments.Node{},
-		NPM:           &segments.Npm{},
-		NX:            &segments.Nx{},
-		OS:            &segments.Os{},
-		OWM:           &segments.Owm{},
-		PATH:          &segments.Path{},
-		PERL:          &segments.Perl{},
-		PHP:           &segments.Php{},
-		PLASTIC:       &segments.Plastic{},
-		PROJECT:       &segments.Project{},
-		PYTHON:        &segments.Python{},
-		R:             &segments.R{},
-		ROOT:          &segments.Root{},
-		RUBY:          &segments.Ruby{},
-		RUST:          &segments.Rust{},
-		SESSION:       &segments.Session{},
-		SHELL:         &segments.Shell{},
-		SPOTIFY:       &segments.Spotify{},
-		STRAVA:        &segments.Strava{},
-		SVN:           &segments.Svn{},
-		SWIFT:         &segments.Swift{},
-		SYSTEMINFO:    &segments.SystemInfo{},
-		TERRAFORM:     &segments.Terraform{},
-		TEXT:          &segments.Text{},
-		TIME:          &segments.Time{},
-		UI5TOOLING:    &segments.UI5Tooling{},
-		WAKATIME:      &segments.Wakatime{},
-		WINREG:        &segments.WindowsRegistry{},
-		WITHINGS:      &segments.Withings{},
-		XMAKE:         &segments.XMake{},
-		YTM:           &segments.Ytm{},
-	}
+
 	if segment.Properties == nil {
 		segment.Properties = make(properties.Map)
 	}
-	if writer, ok := functions[segment.Type]; ok {
+
+	if f, ok := Segments[segment.Type]; ok {
+		writer := f()
 		writer.Init(segment.Properties, env)
 		segment.writer = writer
 		return nil
 	}
+
 	return errors.New("unable to map writer")
 }
 
@@ -396,6 +432,9 @@ func (segment *Segment) SetEnabled(env platform.Environment) {
 			}
 		}
 	}
+	if shouldHideForWidth(segment.env, segment.MinWidth, segment.MaxWidth) {
+		return
+	}
 	if segment.writer.Enabled() {
 		segment.Enabled = true
 		name := segment.Alias
