@@ -10,10 +10,6 @@ import (
 	"io/fs"
 	"net/http"
 	"net/http/httputil"
-	"oh-my-posh/log"
-	"oh-my-posh/platform/battery"
-	"oh-my-posh/platform/cmd"
-	"oh-my-posh/regex"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -23,6 +19,11 @@ import (
 	"sync"
 	"time"
 
+	"github.com/jandedobbeleer/oh-my-posh/log"
+	"github.com/jandedobbeleer/oh-my-posh/platform/battery"
+	"github.com/jandedobbeleer/oh-my-posh/platform/cmd"
+	"github.com/jandedobbeleer/oh-my-posh/regex"
+
 	process "github.com/shirou/gopsutil/v3/process"
 )
 
@@ -42,7 +43,6 @@ func getPID() string {
 }
 
 var (
-	lock          = sync.RWMutex{}
 	TEMPLATECACHE = fmt.Sprintf("template_cache_%s", getPID())
 	TOGGLECACHE   = fmt.Sprintf("toggle_cache_%s", getPID())
 )
@@ -62,6 +62,7 @@ type Flags struct {
 	Strict        bool
 	Debug         bool
 	Manual        bool
+	Plain         bool
 }
 
 type CommandError struct {
@@ -130,8 +131,8 @@ type Connection struct {
 
 type SegmentsCache map[string]interface{}
 
-func (c *SegmentsCache) Contains(key string) bool {
-	_, ok := (*c)[key]
+func (s *SegmentsCache) Contains(key string) bool {
+	_, ok := (*s)[key]
 	return ok
 }
 
@@ -148,15 +149,14 @@ type TemplateCache struct {
 	OS           string
 	WSL          bool
 	Segments     SegmentsCache
+
+	sync.RWMutex
 }
 
 func (t *TemplateCache) AddSegmentData(key string, value interface{}) {
-	lock.Lock()
-	defer lock.Unlock()
-	if t.Segments == nil {
-		t.Segments = make(map[string]interface{})
-	}
+	t.Lock()
 	t.Segments[key] = value
+	t.Unlock()
 }
 
 type Environment interface {
@@ -211,15 +211,15 @@ type Environment interface {
 }
 
 type commandCache struct {
-	commands *concurrentMap
+	commands *ConcurrentMap
 }
 
 func (c *commandCache) set(command, path string) {
-	c.commands.set(command, path)
+	c.commands.Set(command, path)
 }
 
 func (c *commandCache) get(command string) (string, bool) {
-	cacheCommand, found := c.commands.get(command)
+	cacheCommand, found := c.commands.Get(command)
 	if !found {
 		return "", false
 	}
@@ -236,6 +236,8 @@ type Shell struct {
 	fileCache *fileCache
 	tmplCache *TemplateCache
 	networks  []*Connection
+
+	sync.RWMutex
 }
 
 func (env *Shell) Init() {
@@ -250,7 +252,7 @@ func (env *Shell) Init() {
 	env.fileCache.Init(env.CachePath())
 	env.resolveConfigPath()
 	env.cmdCache = &commandCache{
-		commands: newConcurrentMap(),
+		commands: NewConcurrentMap(),
 	}
 }
 
@@ -330,9 +332,7 @@ func (env *Shell) Getenv(key string) string {
 
 func (env *Shell) Pwd() string {
 	defer env.Trace(time.Now(), "Pwd")
-	lock.Lock()
 	defer func() {
-		lock.Unlock()
 		env.Debug("Pwd", env.cwd)
 	}()
 	if env.cwd != "" {
@@ -531,12 +531,6 @@ func (env *Shell) CommandPath(command string) string {
 		env.Debug("CommandPath", path)
 		return path
 	}
-	path, err = env.LookWinAppPath(command)
-	if err == nil {
-		env.cmdCache.set(command, path)
-		env.Debug("CommandPath", path)
-		return path
-	}
 	env.Error("CommandPath", err)
 	return ""
 }
@@ -581,7 +575,7 @@ func (env *Shell) Shell() string {
 	}
 	env.Debug("Shell", "process name: "+name)
 	// this is used for when scoop creates a shim, see
-	// https://github.com/JanDeDobbeleer/oh-my-posh/issues/2806
+	// https://github.com/jandedobbeleer/oh-my-posh/issues/2806
 	executable, _ := os.Executable()
 	if name == "cmd.exe" || name == executable {
 		p, _ = p.Parent()
@@ -713,7 +707,11 @@ func (env *Shell) Logs() string {
 }
 
 func (env *Shell) TemplateCache() *TemplateCache {
-	defer env.Trace(time.Now(), "TemplateCache")
+	env.Lock()
+	defer func() {
+		env.Trace(time.Now(), "TemplateCache")
+		env.Unlock()
+	}()
 	if env.tmplCache != nil {
 		return env.tmplCache
 	}
@@ -723,6 +721,7 @@ func (env *Shell) TemplateCache() *TemplateCache {
 		ShellVersion: env.CmdFlags.ShellVersion,
 		Code:         env.ErrorCode(),
 		WSL:          env.IsWsl(),
+		Segments:     make(map[string]interface{}),
 	}
 	tmplCache.Env = make(map[string]string)
 	const separator = "="
@@ -756,8 +755,6 @@ func (env *Shell) TemplateCache() *TemplateCache {
 }
 
 func (env *Shell) DirMatchesOneOf(dir string, regexes []string) (match bool) {
-	lock.Lock()
-	defer lock.Unlock()
 	// sometimes the function panics inside golang, we want to silence that error
 	// and assume that there's no match. Not perfect, but better than crashing
 	// for the time being until we figure out what the actual root cause is
