@@ -2,10 +2,11 @@ package segments
 
 import (
 	"errors"
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
 	"path"
 
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
+
 	"gopkg.in/ini.v1"
 )
 
