@@ -5,8 +5,9 @@ import (
 	"errors"
 	"fmt"
 	"math"
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
+
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
 )
 
 type Owm struct {
