@@ -2,13 +2,14 @@ package segments
 
 import (
 	"fmt"
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
-	"oh-my-posh/regex"
-	"oh-my-posh/shell"
-	"oh-my-posh/template"
 	"sort"
 	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/regex"
+	"github.com/jandedobbeleer/oh-my-posh/shell"
+	"github.com/jandedobbeleer/oh-my-posh/template"
 )
 
 type Path struct {
@@ -23,6 +24,7 @@ type Path struct {
 	StackCount int
 	Location   string
 	Writable   bool
+	RootDir    bool
 }
 
 const (
@@ -374,7 +376,7 @@ func (pt *Path) getAgnosterShortPath() string {
 func (pt *Path) getFullPath() string {
 	rel := pt.relative
 	pathSeparator := pt.env.PathSeparator()
-	if pt.root != pathSeparator && !strings.HasSuffix(pt.root, pathSeparator) {
+	if len(pt.root) != 0 && pt.root != pathSeparator && !strings.HasSuffix(pt.root, pathSeparator) {
 		rel = pathSeparator + rel
 	}
 	path := pt.replaceFolderSeparators(rel)
@@ -427,6 +429,9 @@ func (pt *Path) replaceMappedLocations() (string, string) {
 	sort.Sort(sort.Reverse(sort.StringSlice(keys)))
 
 	root, relative := pt.parsePath(pt.pwd)
+	if len(relative) == 0 {
+		pt.RootDir = true
+	}
 	rootN := pt.normalize(root)
 	relativeN := pt.normalize(relative)
 	pathSeparator := pt.env.PathSeparator()
