@@ -1,14 +1,15 @@
 package segments
 
 import (
-	"oh-my-posh/mock"
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
-	"oh-my-posh/shell"
-	"oh-my-posh/template"
 	"strings"
 	"testing"
 
+	"github.com/jandedobbeleer/oh-my-posh/mock"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/shell"
+	"github.com/jandedobbeleer/oh-my-posh/template"
+
 	"github.com/stretchr/testify/assert"
 	mock2 "github.com/stretchr/testify/mock"
 )
@@ -1355,6 +1356,8 @@ func TestReplaceMappedLocations(t *testing.T) {
 		{Pwd: "/f/g/h/e", Expected: "^/e"},
 		{Pwd: "/a/b/c/d", Expected: "#"},
 		{Pwd: "/a/b/c/d/e", Expected: "#/e"},
+		{Pwd: "/a/b/c/d/e", Expected: "#/e"},
+		{Pwd: "/a/b/k/j/e", Expected: "e"},
 	}
 
 	for _, tc := range cases {
@@ -1363,6 +1366,7 @@ func TestReplaceMappedLocations(t *testing.T) {
 		env.On("Pwd").Return(tc.Pwd)
 		env.On("Shell").Return(shell.FISH)
 		env.On("GOOS").Return(platform.DARWIN)
+		env.On("Home").Return("/a/b/k")
 		path := &Path{
 			env: env,
 			props: properties.Map{
@@ -1371,6 +1375,7 @@ func TestReplaceMappedLocations(t *testing.T) {
 					"/a/b/c/d": "#",
 					"/f/g/h/*": "^",
 					"/c/l/k/*": "",
+					"~/j/*":    "",
 				},
 			},
 		}
