@@ -4,12 +4,13 @@ import (
 	"encoding/json"
 	"encoding/xml"
 	"errors"
-	"oh-my-posh/platform"
-	"oh-my-posh/properties"
-	"oh-my-posh/regex"
 	"path/filepath"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/regex"
+
 	"github.com/BurntSushi/toml"
 )
 
@@ -20,18 +21,12 @@ type ProjectItem struct {
 }
 
 type ProjectData struct {
+	Type    string
 	Version string
 	Name    string
 	Target  string
 }
 
-func (p *ProjectData) enabled() bool {
-	if p == nil {
-		return false
-	}
-	return len(p.Version) > 0 || len(p.Name) > 0 || len(p.Target) > 0
-}
-
 // Rust Cargo package
 type CargoTOML struct {
 	Package ProjectData
@@ -72,10 +67,11 @@ func (n *Project) Enabled() bool {
 				continue
 			}
 			n.ProjectData = *data
-			return n.enabled()
+			n.ProjectData.Type = item.Name
+			return true
 		}
 	}
-	return false
+	return n.props.GetBool(properties.AlwaysEnabled, false)
 }
 
 func (n *Project) Template() string {
@@ -117,6 +113,11 @@ func (n *Project) Init(props properties.Properties, env platform.Environment) {
 			Files:   []string{"*.vbproj", "*.fsproj", "*.csproj"},
 			Fetcher: n.getDotnetProject,
 		},
+		{
+			Name:    "julia",
+			Files:   []string{"JuliaProject.toml", "Project.toml"},
+			Fetcher: n.getProjectData,
+		},
 	}
 }
 
@@ -226,3 +227,16 @@ func (n *Project) getDotnetProject(item ProjectItem) *ProjectData {
 		Name:   name,
 	}
 }
+
+func (n *Project) getProjectData(item ProjectItem) *ProjectData {
+	content := n.env.FileContent(item.Files[0])
+
+	var data ProjectData
+	_, err := toml.Decode(content, &data)
+	if err != nil {
+		n.Error = err.Error()
+		return nil
+	}
+
+	return &data
+}
