@@ -1,10 +1,11 @@
 package template
 
 import (
-	"oh-my-posh/mock"
-	"oh-my-posh/platform"
 	"testing"
 
+	"github.com/jandedobbeleer/oh-my-posh/mock"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+
 	"github.com/stretchr/testify/assert"
 	mock2 "github.com/stretchr/testify/mock"
 )
