@@ -1,6 +1,6 @@
 package template
 
-import "oh-my-posh/regex"
+import "github.com/jandedobbeleer/oh-my-posh/regex"
 
 func matchP(pattern, text string) bool {
 	return regex.MatchString(pattern, text)
