@@ -3,10 +3,11 @@ package template
 import (
 	"bytes"
 	"errors"
-	"oh-my-posh/platform"
-	"oh-my-posh/regex"
 	"strings"
 	"text/template"
+
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/regex"
 )
 
 const (
@@ -58,7 +59,11 @@ func (t *Text) Render() (string, error) {
 	err = tmpl.Execute(buffer, context)
 	if err != nil {
 		t.Env.Error("Render", err)
-		return "", errors.New(IncorrectTemplate)
+		msg := regex.FindNamedRegexMatch(`at (?P<MSG><.*)$`, err.Error())
+		if len(msg) == 0 {
+			return "", errors.New(IncorrectTemplate)
+		}
+		return "", errors.New(msg["MSG"])
 	}
 	text := buffer.String()
 	// issue with missingkey=zero ignored for map[string]interface{}
@@ -104,10 +109,23 @@ func (t *Text) cleanTemplate() {
 		return false
 	}
 
-	var result string
-	var property string
-	var inProperty bool
-	for _, char := range t.Template {
+	var result, property string
+	var inProperty, inTemplate bool
+	for i, char := range t.Template {
+		// define start or end of template
+		if !inTemplate && char == '{' {
+			if i-1 >= 0 && rune(t.Template[i-1]) == '{' {
+				inTemplate = true
+			}
+		} else if inTemplate && char == '}' {
+			if i-1 >= 0 && rune(t.Template[i-1]) == '}' {
+				inTemplate = false
+			}
+		}
+		if !inTemplate {
+			result += string(char)
+			continue
+		}
 		switch char {
 		case '.':
 			var lastChar rune
