@@ -1,10 +1,11 @@
 package template
 
 import (
-	"oh-my-posh/mock"
-	"oh-my-posh/platform"
 	"testing"
 
+	"github.com/jandedobbeleer/oh-my-posh/mock"
+	"github.com/jandedobbeleer/oh-my-posh/platform"
+
 	"github.com/stretchr/testify/assert"
 	mock2 "github.com/stretchr/testify/mock"
 )
@@ -20,6 +21,12 @@ func TestRenderTemplate(t *testing.T) {
 		ShouldError bool
 		Context     interface{}
 	}{
+		{
+			Case:     "dot literal",
+			Expected: "Hello .NET \uE77F",
+			Template: "{{ .Text }} .NET \uE77F",
+			Context:  struct{ Text string }{Text: "Hello"},
+		},
 		{
 			Case:     "color override with dots",
 			Expected: "😺💬<#FF8000> Meow! What should I do next? ...</>",
